"use strict";
/*
Copyright 2022 The Matrix.org Foundation C.I.C.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.ArrayBlock = void 0;
const InvalidBlockError_1 = require("./InvalidBlockError");
const BaseBlock_1 = require("./BaseBlock");
const AjvContainer_1 = require("../AjvContainer");
/**
 * Represents an array-based content block.
 * @module Content Blocks
 */
class ArrayBlock extends BaseBlock_1.BaseBlock {
    /**
     * Creates a new ArrayBlock.
     * @param name The name of the block, for error messages and debugging.
     * @param raw The block's value.
     * @protected
     */
    constructor(name, raw) {
        super(name, raw);
        if (!ArrayBlock.validateFn(raw)) {
            throw new InvalidBlockError_1.InvalidBlockError(name, ArrayBlock.validateFn.errors);
        }
    }
}
exports.ArrayBlock = ArrayBlock;
ArrayBlock.schema = {
    type: "array",
    errorMessage: "should be an array value",
};
ArrayBlock.validateFn = AjvContainer_1.AjvContainer.ajv.compile(ArrayBlock.schema);
//# sourceMappingURL=ArrayBlock.js.map