import { MarkupBlock, WireMarkupBlock } from "./MarkupBlock";
import { ObjectBlock } from "../ObjectBlock";
import { EitherAnd } from "../../types";
import { Schema } from "ajv";
import { UnstableValue } from "../../NamespacedValue";
/**
 * Types for notice blocks over the wire.
 * @module Matrix Content Blocks
 * @see NoticeBlock
 */
export declare module WireNoticeBlock {
    type Primary = {
        [MarkupBlock.type.name]: WireMarkupBlock.Representation[];
    };
    type Secondary = {
        [MarkupBlock.type.altName]: WireMarkupBlock.Representation[];
    };
    export type Value = EitherAnd<Primary, Secondary>;
    export {};
}
/**
 * A "notice" block, or a block meant to represent that the surrounding event can
 * be rendered as a notice. Contains a MarkupBlock internally.
 * @module Matrix Content Blocks
 * @see MarkupBlock
 */
export declare class NoticeBlock extends ObjectBlock<WireNoticeBlock.Value> {
    static readonly schema: Schema;
    static readonly validateFn: import("ajv").ValidateFunction<unknown>;
    static readonly type: UnstableValue<"m.notice", "org.matrix.msc1767.notice">;
    private lazyMarkup;
    constructor(raw: WireNoticeBlock.Value);
    get markup(): MarkupBlock;
}
