"use strict";
/*
Copyright 2022 The Matrix.org Foundation C.I.C.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.NoticeBlock = void 0;
const MarkupBlock_1 = require("./MarkupBlock");
const ObjectBlock_1 = require("../ObjectBlock");
const AjvContainer_1 = require("../../AjvContainer");
const NamespacedValue_1 = require("../../NamespacedValue");
const InvalidBlockError_1 = require("../InvalidBlockError");
const LazyValue_1 = require("../../LazyValue");
/**
 * A "notice" block, or a block meant to represent that the surrounding event can
 * be rendered as a notice. Contains a MarkupBlock internally.
 * @module Matrix Content Blocks
 * @see MarkupBlock
 */
class NoticeBlock extends ObjectBlock_1.ObjectBlock {
    constructor(raw) {
        super(NoticeBlock.type.stable, raw);
        this.lazyMarkup = new LazyValue_1.LazyValue(() => new MarkupBlock_1.MarkupBlock(MarkupBlock_1.MarkupBlock.type.findIn(this.raw)));
        if (!NoticeBlock.validateFn(raw)) {
            throw new InvalidBlockError_1.InvalidBlockError(this.name, NoticeBlock.validateFn.errors);
        }
    }
    get markup() {
        return this.lazyMarkup.value;
    }
}
exports.NoticeBlock = NoticeBlock;
NoticeBlock.schema = AjvContainer_1.AjvContainer.eitherAnd(MarkupBlock_1.MarkupBlock.type, MarkupBlock_1.MarkupBlock.schema);
NoticeBlock.validateFn = AjvContainer_1.AjvContainer.ajv.compile(NoticeBlock.schema);
NoticeBlock.type = new NamespacedValue_1.UnstableValue("m.notice", "org.matrix.msc1767.notice");
//# sourceMappingURL=NoticeBlock.js.map