import { WireMessageEvent } from "./MessageEvent";
import { WireEvent } from "../types_wire";
import { UnstableValue } from "../../NamespacedValue";
import { MarkupBlock } from "../../content_blocks/m/MarkupBlock";
import { RoomEvent } from "../RoomEvent";
import { Schema } from "ajv";
/**
 * Types for emote events over the wire.
 * @module Matrix Events
 * @see EmoteEvent
 */
export declare module WireEmoteEvent {
    type ContentValue = WireMessageEvent.ContentValue;
}
/**
 * An emote event, containing a MarkupBlock for content.
 * @module Matrix Events
 * @see MarkupBlock
 */
export declare class EmoteEvent extends RoomEvent<WireEmoteEvent.ContentValue> {
    static readonly contentSchema: Schema;
    static readonly contentValidateFn: import("ajv").ValidateFunction<unknown>;
    static readonly type: UnstableValue<"m.emote", "org.matrix.msc1767.emote">;
    private lazyMarkup;
    constructor(raw: WireEvent.RoomEvent<WireMessageEvent.ContentValue>);
    /**
     * The markup block for the event.
     */
    get markup(): MarkupBlock;
    /**
     The text representation of the event, if one is present.
     */
    get text(): string | undefined;
    /**
     The HTML representation of the event, if one is present.
     */
    get html(): string | undefined;
}
