"use strict";
/*
Copyright 2022 The Matrix.org Foundation C.I.C.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.EmoteEvent = void 0;
const NamespacedValue_1 = require("../../NamespacedValue");
const MarkupBlock_1 = require("../../content_blocks/m/MarkupBlock");
const RoomEvent_1 = require("../RoomEvent");
const AjvContainer_1 = require("../../AjvContainer");
const LazyValue_1 = require("../../LazyValue");
const InvalidEventError_1 = require("../InvalidEventError");
const EventParser_1 = require("../EventParser");
const EmoteBlock_1 = require("../../content_blocks/m/EmoteBlock");
/**
 * An emote event, containing a MarkupBlock for content.
 * @module Matrix Events
 * @see MarkupBlock
 */
class EmoteEvent extends RoomEvent_1.RoomEvent {
    constructor(raw) {
        super(EmoteEvent.type.stable, raw, false);
        this.lazyMarkup = new LazyValue_1.LazyValue(() => new MarkupBlock_1.MarkupBlock(MarkupBlock_1.MarkupBlock.type.findIn(this.content)));
        if (!EmoteEvent.contentValidateFn(this.content)) {
            throw new InvalidEventError_1.InvalidEventError(this.name, EmoteEvent.contentValidateFn.errors);
        }
    }
    /**
     * The markup block for the event.
     */
    get markup() {
        return this.lazyMarkup.value;
    }
    /**
     The text representation of the event, if one is present.
     */
    get text() {
        return this.markup.text;
    }
    /**
     The HTML representation of the event, if one is present.
     */
    get html() {
        return this.markup.html;
    }
}
exports.EmoteEvent = EmoteEvent;
EmoteEvent.contentSchema = AjvContainer_1.AjvContainer.eitherAnd(MarkupBlock_1.MarkupBlock.type, MarkupBlock_1.MarkupBlock.schema);
EmoteEvent.contentValidateFn = AjvContainer_1.AjvContainer.ajv.compile(EmoteEvent.contentSchema);
EmoteEvent.type = new NamespacedValue_1.UnstableValue("m.emote", "org.matrix.msc1767.emote");
(() => {
    // Register the event type as a default event type
    (0, EventParser_1.addInternalKnownEventParser)(EmoteEvent.type, (x) => new EmoteEvent(x));
    // Also register an unknown event parser for handling
    (0, EventParser_1.addInternalUnknownEventParser)(EventParser_1.InternalOrderCategorization.RichTextOrFile, x => {
        const possibleBlock = EmoteBlock_1.EmoteBlock.type.findIn(x.content);
        if (!!possibleBlock) {
            const block = new EmoteBlock_1.EmoteBlock(possibleBlock);
            return new EmoteEvent(Object.assign(Object.assign({}, x), { type: EmoteEvent.type.name, content: block.raw }));
        }
        else {
            return undefined; // not likely to be parsable by us
        }
    });
})();
//# sourceMappingURL=EmoteEvent.js.map