import { RoomEvent } from "../RoomEvent";
import { MarkupBlock, WireMarkupBlock } from "../../content_blocks/m/MarkupBlock";
import { EitherAnd } from "../../types";
import { Schema } from "ajv";
import { UnstableValue } from "../../NamespacedValue";
import { WireEvent } from "../types_wire";
/**
 * Types for message events over the wire.
 * @module Matrix Events
 * @see MessageEvent
 */
export declare module WireMessageEvent {
    type PrimaryContent = {
        [MarkupBlock.type.name]: WireMarkupBlock.Representation[];
    };
    type SecondaryContent = {
        [MarkupBlock.type.altName]: WireMarkupBlock.Representation[];
    };
    export type ContentValue = EitherAnd<PrimaryContent, SecondaryContent>;
    export {};
}
/**
 * A message event, containing a MarkupBlock for content.
 * @module Matrix Events
 * @see MarkupBlock
 */
export declare class MessageEvent extends RoomEvent<WireMessageEvent.ContentValue> {
    static readonly contentSchema: Schema;
    static readonly contentValidateFn: import("ajv").ValidateFunction<unknown>;
    static readonly type: UnstableValue<"m.message", "org.matrix.msc1767.message">;
    private lazyMarkup;
    constructor(raw: WireEvent.RoomEvent<WireMessageEvent.ContentValue>);
    /**
     * The markup block for the event.
     */
    get markup(): MarkupBlock;
    /**
     The text representation of the event, if one is present.
     */
    get text(): string | undefined;
    /**
     The HTML representation of the event, if one is present.
     */
    get html(): string | undefined;
}
